==> bonita-common-6.1.1-sources.jar: org/bonitasoft/engine/bpm/connector/ConnectorCriterion.java <==
/**
 * Copyright (C) 2012 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.connector;

/**
 * @author Yanyan Liu
 */
public enum ConnectorCriterion {
    /*
     * connector definition id ascending order
     */
    DEFINITION_ID_ASC,
    /*
     * connector definition id descending order
     */
    DEFINITION_ID_DESC,
    /*
     * connector definition version ascending order
     */
    DEFINITION_VERSION_ASC,
    /*
     * connector definition version descending order
     */
    DEFINITION_VERSION_DESC,
    /*
     * connector implementation id ascending order
     */
    IMPLEMENTATION_ID_ASC,
    /*
     * connector implementation id descending order
     */
    IMPLEMENTATION_ID_DESC,
    /*
     * connector implementation version ascending order
     */
    IMPLEMENTATION_VERSION_ASC,
    /*
     * connector implementation version descending order
     */
    IMPLEMENTATIONN_VERSION_DESC,
    /*
     * connector implementation class name ascending order
     */
    IMPLEMENTATIONN_CLASS_NAME_ACS,
    /*
     * connector implementation class name descending order
     */
    IMPLEMENTATIONN_CLASS_NAME_DESC,
    /*
     * connector implementation id ascending order
     */
    DEFAULT
}

==> bonita-common-6.3.1-sources.jar: org/bonitasoft/engine/bpm/connector/ConnectorCriterion.java <==
/**
 * Copyright (C) 2012, 2014 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.connector;

/**
 * Criterion to sort connectors
 * 
 * @author Yanyan Liu
 * @author Celine Souchet
 */
public enum ConnectorCriterion {
    /**
     * By ascending identifier of connector definition
     */
    DEFINITION_ID_ASC,

    /**
     * By descending identifier of connector definition
     */
    DEFINITION_ID_DESC,

    /**
     * By ascending version of connector definition
     * 
     */
    DEFINITION_VERSION_ASC,

    /**
     * By descending version of connector definition
     */
    DEFINITION_VERSION_DESC,

    /**
     * By ascending identifier of connector implementation
     */
    
    IMPLEMENTATION_ID_ASC,
    
    /**
     * By descending identifier of connector implementation
     */
    IMPLEMENTATION_ID_DESC,
    
    /**
     * By ascending version of connector implementation
     */
    IMPLEMENTATION_VERSION_ASC,
    
    /**
     * By descending version of connector implementation
     */
    IMPLEMENTATIONN_VERSION_DESC,
    
    /**
     * By ascending class name of connector implementation
     */
    IMPLEMENTATIONN_CLASS_NAME_ACS,
    
    /**
     * By descending class name of connector implementation
     */
    IMPLEMENTATIONN_CLASS_NAME_DESC,
    
    /**
     * By descending identifier of connector implementation
     */
    DEFAULT
}
